# Obsidian Daylio to Markdown Parser
Daylio is an amazing journaling and mood-tracking app, but you may want to store your journals also in an Obsidian Vault. For that you need a "translator" (or a parser, more technically speaking) that knows how to transfer Daylio entries into Obsidian notes.

![Daylio to Obsidian](https://user-images.githubusercontent.com/59067099/198896455-41bb9496-7efc-4102-b311-f1db614a2d96.png)

## Installation
If you are an end-user and wish to just convert your .csv file into markdown:
```commandline
pip install obsidian-daylio-parser
daylio_to_md --help
```

If you are a developer and wish to contribute to the project, clone this repo and submit your commits in a pull request.
```